@@ -12,7 +12,7 @@ use Tickit::Widget::HBox;
 
 my $tickit = Tickit->new();
 
-my @basekeys = qw( a i Space Tab Enter Up Escape );
+my @basekeys = qw( a h i Space Backspace Tab Enter Up Escape );
 
 my $vbox = Tickit::Widget::VBox->new( spacing => 1 );
 my $hbox;
