@@ -33,7 +33,7 @@ sub on_key
    my ( $args ) = @_;
 
    if( $args->type eq "text" and $args->str =~ m/[0-7]/ ) {
-      $self->pen->chattr( fg => $args->str );
+      $self->set_style( fg => $args->str );
       $self->redraw;
       return 1;
    }
