@@ -32,15 +32,17 @@ sub _modstr
 
 # Mass hackery
 $tickit->term->bind_event( key => sub {
-   my ( undef, $ev, $args ) = @_;
-   my ( $type, $str, $mod ) = @{$args}{qw( type str mod )};
-   $keydisplay->set_text( "$type $str (mod=" . _modstr($mod) . ")" );
+   my ( undef, $ev, $info ) = @_;
+   $keydisplay->set_text( sprintf "%s %s (mod=%s)",
+      $info->type, $info->str, _modstr( $info->mod )
+   );
 } );
 
 $tickit->term->bind_event( mouse => sub {
-   my ( undef, $ev, $args ) = @_;
-   my ( $type, $button, $line, $col, $mod ) = @{$args}{qw( type button line col mod )};
-   $mousedisplay->set_text( "$type button $button at ($line,$col) (mod=" . _modstr($mod) . ")" );
+   my ( undef, $ev, $info ) = @_;
+   $mousedisplay->set_text( sprintf "%s button %s at (%d,%d) (mod=%s)",
+      $info->type, $info->button, $info->line, $info->col, _modstr( $info->mod )
+   );
 } );
 
 $tickit->run;
